Commandline Args — Shopyo documentation

# Commandline Args

Various commandline args exist to ease your life. The initialise command for example is a combination of many commands

Note

You can run

    shopyo <command>

or

      python manage.py <command>

    except for the ``shopyo new ...``` command

    shopyo new blog
    cd blog
    python -m pip install -r requirements.txt
    cd blog
    python manage.py initialise
    python manage.py rundebug

## Complete commands

Db from scratch

    python manage.py db init # create db from new

Migrate

    python manage.py db migrate
    python manage.py db upgrade

Clean

    python manage.py clean

removes `__pycache__/`, `shopyo.db` and `migrations`.

Initialise

    shopyo initialise

Run server

    python manage.py runserver

Collect static

    python manage.py collectstatic

    python manage.py collectstatic demoapp

    python manage.py collectstatic box__somebox/demoapp